Module: Synchronized::ClassMethods

Included in:
Mailbox::ClassMethods
Defined in:
lib/synchronized.rb

Instance Method Summary collapse

Instance Method Details

#synchronized ⇒ Object

Notify Mailbox that the next method added will be synchronized.

This guarentees: 1. Two invocations of this method will not interleave and 2. a happens-before relationship is established with any subsequent invocation. http://java.sun.com/docs/books/tutorial/essential/concurrency/syncmeth.html



29
30
31
# File 'lib/synchronized.rb', line 29

def synchronized
  @synchronized = true
end